---
orphan: true
---

# Tutorials

The easiest way to get familiar with ehrdata is to follow along with our tutorials.
Many are also designed to work seamlessly in Binder, a free cloud computing platform.

## Quick start

```{toctree}
:maxdepth: 3

getting_started
omop_tables_tutorial
tutorial_time_series_with_pypots
omop_ml
physionet2012
```
